==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebCalendarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescriptionMetadata } from "./CalendarFormatOptionsDescriptionMetadata";
import { WebCalendarResourceStringsDescriptionMetadata } from "./WebCalendarResourceStringsDescriptionMetadata";
import { WebComponentDataValueChangedEventArgsDescriptionMetadata } from "./WebComponentDataValueChangedEventArgsDescriptionMetadata";
import { WebCalendarBaseDescriptionMetadata } from "./WebCalendarBaseDescriptionMetadata";
import { WebCalendarDescription } from "./WebCalendarDescription";
/**
 * @hidden
 */
export let WebCalendarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarDescriptionMetadata.a == null) {
                WebCalendarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarDescriptionMetadata.c(WebCalendarDescriptionMetadata.a);
            }
            if (a.j(WebCalendarDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCalendarDescriptionMetadata.a);
            CalendarFormatOptionsDescriptionMetadata.d(a);
            WebCalendarResourceStringsDescriptionMetadata.d(a);
            WebComponentDataValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebCalendarBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Calendar");
            a.item("__tagNameWC", "String:igc-calendar");
            a.item("Value", "Date");
            a.item("Values", "Array:Date");
            a.item("ActiveDate", "Date");
            a.item("HideOutsideDays", "Boolean");
            a.item("HideHeader", "Boolean");
            a.item("HeaderOrientation", "ExportedType:string:CalendarHeaderOrientation");
            a.item("HeaderOrientation@names", "Vertical;Horizontal");
            a.item("Orientation", "ExportedType:string:CalendarOrientation");
            a.item("Orientation@names", "Vertical;Horizontal");
            a.item("VisibleMonths", "Number:double");
            a.item("ActiveView", "ExportedType:string:CalendarActiveView");
            a.item("ActiveView@names", "Days;Months;Years");
            a.item("FormatOptions", "ExportedType:CalendarFormatOptions");
            a.item("ResourceStrings", "ExportedType:WebCalendarResourceStrings");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebCalendarDescriptionMetadata.b(a);
            a.aa("WebCalendar", () => new WebCalendarDescription());
            a.z("WebCalendar", WebCalendarDescriptionMetadata.a);
        }
    }
    WebCalendarDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCalendarDescriptionMetadata, 'WebCalendarDescriptionMetadata');
    WebCalendarDescriptionMetadata.a = null;
    return WebCalendarDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebCalendarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarFormatOptionsDescriptionMetadata } from "./CalendarFormatOptionsDescriptionMetadata";
import { WebCalendarResourceStringsDescriptionMetadata } from "./WebCalendarResourceStringsDescriptionMetadata";
import { WebComponentDataValueChangedEventArgsDescriptionMetadata } from "./WebComponentDataValueChangedEventArgsDescriptionMetadata";
import { WebCalendarBaseDescriptionMetadata } from "./WebCalendarBaseDescriptionMetadata";
import { WebCalendarDescription } from "./WebCalendarDescription";
/**
 * @hidden
 */
export let WebCalendarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCalendarDescriptionMetadata extends Base {
        static b(a) {
            if (WebCalendarDescriptionMetadata.a == null) {
                WebCalendarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCalendarDescriptionMetadata.c(WebCalendarDescriptionMetadata.a);
            }
            if (a.k(WebCalendarDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCalendarDescriptionMetadata.a);
            CalendarFormatOptionsDescriptionMetadata.d(a);
            WebCalendarResourceStringsDescriptionMetadata.d(a);
            WebComponentDataValueChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebCalendarBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Calendar");
            a.item("__tagNameWC", "String:igc-calendar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "Date");
            a.item("Values", "Array:Date");
            a.item("ActiveDate", "Date");
            a.item("HideOutsideDays", "Boolean");
            a.item("HideHeader", "Boolean");
            a.item("HeaderOrientation", "ExportedType:string:CalendarHeaderOrientation");
            a.item("HeaderOrientation@names", "Vertical;Horizontal");
            a.item("Orientation", "ExportedType:string:CalendarOrientation");
            a.item("Orientation@names", "Vertical;Horizontal");
            a.item("VisibleMonths", "Number:double");
            a.item("ActiveView", "ExportedType:string:CalendarActiveView");
            a.item("ActiveView@names", "Days;Months;Years");
            a.item("FormatOptions", "ExportedType:CalendarFormatOptions");
            a.item("ResourceStrings", "ExportedType:WebCalendarResourceStrings");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebCalendarDescriptionMetadata.b(a);
            a.ac("WebCalendar", () => new WebCalendarDescription());
            a.ab("WebCalendar", WebCalendarDescriptionMetadata.a);
        }
    }
    WebCalendarDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCalendarDescriptionMetadata, 'WebCalendarDescriptionMetadata');
    WebCalendarDescriptionMetadata.a = null;
    return WebCalendarDescriptionMetadata;
})();
